==> nextcloud-26.0.9.tgz: nextcloud/apps/systemtags/l10n/en_GB.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "System tag %1$s added by the system",
    "Added system tag {systemtag}" : "Added system tag {systemtag}",
    "Added system tag %1$s" : "Added system tag %1$s",
    "%1$s added system tag %2$s" : "%1$s added system tag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} added system tag {systemtag}",
    "System tag %1$s removed by the system" : "System tag %1$s removed by the system",
    "Removed system tag {systemtag}" : "Removed system tag {systemtag}",
    "Removed system tag %1$s" : "Removed system tag %1$s",
    "%1$s removed system tag %2$s" : "%1$s removed system tag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} removed system tag {systemtag}",
    "You created system tag %1$s" : "You created system tag %1$s",
    "You created system tag {systemtag}" : "You created system tag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s created system tag %2$s",
    "{actor} created system tag {systemtag}" : "{actor} created system tag {systemtag}",
    "You deleted system tag %1$s" : "You deleted system tag %1$s",
    "You deleted system tag {systemtag}" : "You deleted system tag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s deleted system tag %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} deleted system tag {systemtag}",
    "You updated system tag %2$s to %1$s" : "You updated system tag %2$s to %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "You updated system tag {oldsystemtag} to {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s updated system tag %3$s to %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} updated system tag {oldsystemtag} to {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "System tag %2$s was added to %1$s by the system",
    "System tag {systemtag} was added to {file} by the system" : "System tag {systemtag} was added to {file} by the system",
    "You added system tag %2$s to %1$s" : "You added system tag %2$s to %1$s",
    "You added system tag {systemtag} to {file}" : "You added system tag {systemtag} to {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s added system tag %3$s to %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} added system tag {systemtag} to {file}",
    "System tag %2$s was removed from %1$s by the system" : "System tag %2$s was removed from %1$s by the system",
    "System tag {systemtag} was removed from {file} by the system" : "System tag {systemtag} was removed from {file} by the system",
    "You removed system tag %2$s from %1$s" : "You removed system tag %2$s from %1$s",
    "You removed system tag {systemtag} from {file}" : "You removed system tag {systemtag} from {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removed system tag %3$s from %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removed system tag {systemtag} from {file}",
    "%s (restricted)" : "%s (restricted)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System tags</strong> for a file have been modified",
    "Tags" : "Tags",
    "All tagged %s …" : "All tagged %s …",
    "tagged %s" : "tagged %s",
    "Collaborative tags" : "Collaborative tags",
    "Collaborative tagging functionality which shares tags among users." : "Collaborative tagging functionality which shares tags among users.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)",
    "Collaborative tags …" : "Collaborative tags …",
    "Tag name" : "Tag name",
    "Tag level" : "Tag level",
    "Create" : "Create",
    "Update" : "Update",
    "Delete" : "Delete",
    "Reset" : "Reset",
    "Loading …" : "Loading …",
    "Public" : "Public",
    "Restricted" : "Restricted",
    "Invisible" : "Invisible",
    "Failed to create tag" : "Failed to create tag",
    "Failed to delete tag" : "Failed to delete tag",
    "Loading collaborative tags …" : "Loading collaborative tags …",
    "Search or create collaborative tags" : "Search or create collaborative tags",
    "No tags to select, type to create a new tag" : "No tags to select, type to create a new tag",
    "Failed to load tags" : "Failed to load tags",
    "Failed to load selected tags" : "Failed to load selected tags",
    "Failed to select tag" : "Failed to select tag",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them.",
    "This file has the tag {tag}" : "This file has the tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
    "List of tags and their associated files and folders." : "List of tags and their associated files and folders.",
    "No tags found" : "No tags found",
    "Tags you have created will show up here." : "Tags you have created will show up here.",
    "Failed to load last used tags" : "Failed to load last used tags",
    "Missing \"Content-Location\" header" : "Missing \"Content-Location\" header",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Tag name is empty" : "Tag name is empty",
    "Select tag …" : "Select tag …",
    "Tagged files" : "Tagged files",
    "Select tags to filter by" : "Select tags to filter by",
    "Please select tags to filter by" : "Please select tags to filter by",
    "No files found for the selected tags" : "No files found for the selected tags",
    "Create a new tag" : "Create a new tag"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/systemtags/l10n/en_GB.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "System tag %1$s added by the system",
    "Added system tag {systemtag}" : "Added system tag {systemtag}",
    "Added system tag %1$s" : "Added system tag %1$s",
    "%1$s added system tag %2$s" : "%1$s added system tag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} added system tag {systemtag}",
    "System tag %1$s removed by the system" : "System tag %1$s removed by the system",
    "Removed system tag {systemtag}" : "Removed system tag {systemtag}",
    "Removed system tag %1$s" : "Removed system tag %1$s",
    "%1$s removed system tag %2$s" : "%1$s removed system tag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} removed system tag {systemtag}",
    "You created system tag %1$s" : "You created system tag %1$s",
    "You created system tag {systemtag}" : "You created system tag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s created system tag %2$s",
    "{actor} created system tag {systemtag}" : "{actor} created system tag {systemtag}",
    "You deleted system tag %1$s" : "You deleted system tag %1$s",
    "You deleted system tag {systemtag}" : "You deleted system tag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s deleted system tag %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} deleted system tag {systemtag}",
    "You updated system tag %2$s to %1$s" : "You updated system tag %2$s to %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "You updated system tag {oldsystemtag} to {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s updated system tag %3$s to %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} updated system tag {oldsystemtag} to {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "System tag %2$s was added to %1$s by the system",
    "System tag {systemtag} was added to {file} by the system" : "System tag {systemtag} was added to {file} by the system",
    "You added system tag %2$s to %1$s" : "You added system tag %2$s to %1$s",
    "You added system tag {systemtag} to {file}" : "You added system tag {systemtag} to {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s added system tag %3$s to %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} added system tag {systemtag} to {file}",
    "System tag %2$s was removed from %1$s by the system" : "System tag %2$s was removed from %1$s by the system",
    "System tag {systemtag} was removed from {file} by the system" : "System tag {systemtag} was removed from {file} by the system",
    "You removed system tag %2$s from %1$s" : "You removed system tag %2$s from %1$s",
    "You removed system tag {systemtag} from {file}" : "You removed system tag {systemtag} from {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s removed system tag %3$s from %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} removed system tag {systemtag} from {file}",
    "%s (restricted)" : "%s (restricted)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>System tags</strong> for a file have been modified",
    "Tags" : "Tags",
    "All tagged %s …" : "All tagged %s …",
    "tagged %s" : "tagged %s",
    "Collaborative tags" : "Collaborative tags",
    "Collaborative tagging functionality which shares tags among users." : "Collaborative tagging functionality which shares tags among users.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)",
    "Create or edit tags" : "Create or edit tags",
    "Search for a tag to edit" : "Search for a tag to edit",
    "Collaborative tags …" : "Collaborative tags …",
    "No tags to select" : "No tags to select",
    "Tag name" : "Tag name",
    "Tag level" : "Tag level",
    "Create" : "Create",
    "Update" : "Update",
    "Delete" : "Delete",
    "Reset" : "Reset",
    "Loading …" : "Loading …",
    "Public" : "Public",
    "Restricted" : "Restricted",
    "Invisible" : "Invisible",
    "Created tag" : "Created tag",
    "Failed to create tag" : "Failed to create tag",
    "Updated tag" : "Updated tag",
    "Failed to update tag" : "Failed to update tag",
    "Deleted tag" : "Deleted tag",
    "Failed to delete tag" : "Failed to delete tag",
    "Loading collaborative tags …" : "Loading collaborative tags …",
    "Search or create collaborative tags" : "Search or create collaborative tags",
    "No tags to select, type to create a new tag" : "No tags to select, type to create a new tag",
    "Failed to load tags" : "Failed to load tags",
    "Failed to load selected tags" : "Failed to load selected tags",
    "Failed to select tag" : "Failed to select tag",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them.",
    "This file has the tag {tag}" : "This file has the tag {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "This file has the tags {firstTags} and {lastTag}",
    "List of tags and their associated files and folders." : "List of tags and their associated files and folders.",
    "No tags found" : "No tags found",
    "Tags you have created will show up here." : "Tags you have created will show up here.",
    "Failed to load last used tags" : "Failed to load last used tags",
    "Missing \"Content-Location\" header" : "Missing \"Content-Location\" header",
    "Failed to load tags for file" : "Failed to load tags for file",
    "Failed to set tag for file" : "Failed to set tag for file",
    "Failed to delete tag for file" : "Failed to delete tag for file",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Tag name is empty" : "Tag name is empty",
    "Select tag …" : "Select tag …",
    "Tagged files" : "Tagged files",
    "Select tags to filter by" : "Select tags to filter by",
    "Please select tags to filter by" : "Please select tags to filter by",
    "No files found for the selected tags" : "No files found for the selected tags",
    "Create a new tag" : "Create a new tag"
},
"nplurals=2; plural=(n != 1);");
